package com.ff.base.system.mapper;

import com.ff.base.system.domain.SysDatasource;

import java.util.List;

/**
 * 租户数据源Mapper接口
 *
 * @author liukang
 * @date 2024-11-20
 */
public interface SysDatasourceMapper
{
    /**
     * 查询租户数据源
     *
     * @param id 租户数据源主键
     * @return 租户数据源
     */
    public SysDatasource selectSysDatasourceById(Long id);

    /**
     * 按租户id选择sys数据源
     *
     * @param id 身份证件
     * @return {@link SysDatasource }
     */
    SysDatasource selectSysDatasourceByTenantId(String id);

    /**
     * 查询租户数据源列表
     *
     * @param sysDatasource 租户数据源
     * @return 租户数据源集合
     */
    public List<SysDatasource> selectSysDatasourceList(SysDatasource sysDatasource);

    /**
     * 新增租户数据源
     *
     * @param sysDatasource 租户数据源
     * @return 结果
     */
    public int insertSysDatasource(SysDatasource sysDatasource);

    /**
     * 修改租户数据源
     *
     * @param sysDatasource 租户数据源
     * @return 结果
     */
    public int updateSysDatasource(SysDatasource sysDatasource);

    /**
     * 删除租户数据源
     *
     * @param id 租户数据源主键
     * @return 结果
     */
    public int deleteSysDatasourceById(Long id);

    /**
     * 批量删除租户数据源
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysDatasourceByIds(Long[] ids);
}
